@@ -11,6 +11,7 @@ import (
 	_ "github.com/wader/fq/format/avro"
 	_ "github.com/wader/fq/format/bencode"
 	_ "github.com/wader/fq/format/bitcoin"
+	_ "github.com/wader/fq/format/bits"
 	_ "github.com/wader/fq/format/bplist"
 	_ "github.com/wader/fq/format/bson"
 	_ "github.com/wader/fq/format/bzip2"
@@ -42,7 +43,7 @@ import (
 	_ "github.com/wader/fq/format/png"
 	_ "github.com/wader/fq/format/prores"
 	_ "github.com/wader/fq/format/protobuf"
-	_ "github.com/wader/fq/format/raw"
+	_ "github.com/wader/fq/format/riff"
 	_ "github.com/wader/fq/format/rtmp"
 	_ "github.com/wader/fq/format/tar"
 	_ "github.com/wader/fq/format/text"
@@ -51,7 +52,6 @@ import (
 	_ "github.com/wader/fq/format/vorbis"
 	_ "github.com/wader/fq/format/vpx"
 	_ "github.com/wader/fq/format/wasm"
-	_ "github.com/wader/fq/format/wav"
 	_ "github.com/wader/fq/format/webp"
 	_ "github.com/wader/fq/format/xml"
 	_ "github.com/wader/fq/format/yaml"
